@@ -1,4 +1,4 @@
-from .core import PyThread, synchronized, Primitive
+from .core import PyThread, synchronized, Primitive, Timeout
 from .task_queue import Task, TaskQueue
 from .promise import Promise
 import time, uuid, traceback, random
@@ -172,17 +172,17 @@ class Scheduler(PyThread):
         #       int or float - next time to run
         #       None - run at now+interval next time
         #
-        if t is None: t = t0            # alias, t0 is deprecated
+        if t is None: t = t0            # alias, t0 argument is deprecated
         if param is not None:       # for backward compatibility
             params = (param,)
         if id is None:
             id = uuid.uuid4().hex[:8]
-        if t0 is None:
-            t0 = time.time() + (interval or 0.0) + random.random()*jitter
-        elif t0 < 10*365*24*3600:           # ~ Jan 1 1980
-            t0 = time.time() + t0
-        job = Job(self, id, t0, interval, jitter, fcn, count, params, args)
-        return self.add_job(job, t0)
+        if t is None:
+            t = time.time() + (interval or 0.0) + random.random()*jitter
+        elif t < 10*365*24*3600:           # ~ Jan 1 1980
+            t = time.time() + t
+        job = Job(self, id, t, interval, jitter, fcn, count, params, args)
+        return self.add_job(job, t)
         
     @synchronized
     def remove(self, job_or_id):
@@ -215,17 +215,29 @@ class Scheduler(PyThread):
         be on the schedule until it completes or fails.
         """
         return not self.Timeline
+        
+    
+    @synchronized
+    def _next_run(self):
+        # returns run time of first job to run
+        if self.Timeline:
+            return min(j.NextT for j in self.Timeline)
+        else:
+            return None
+
+    @synchronized
+    def _job_is_ready(self):
+        return any(j.NextT <= time.time() for j in self.Timeline)
 
     def run(self):
         while not self.Stop and not (self.is_empty() and self.StopWhenEmpty):
-            delta = 100
-            if self.Timeline:
-                next_t = self.run_jobs()
-                if next_t is not None:
-                    delta = next_t - time.time()
-            if delta > 0:
+            with self:
+                delta = 100
+                if self.Timeline:
+                    next_t = self.run_jobs()
+                    if next_t is not None:
+                        delta = next_t - time.time()
                 self.sleep(delta)
-                
 
     @synchronized        
     def wait_until_empty(self):
@@ -240,17 +252,22 @@ class Scheduler(PyThread):
 _GLobalSchedulerLock = Primitive()
 _GlobalScheduler = None
 
-def init_global_scheduler(name="GlobalScheduler", **args):
+def global_scheduler(name="GlobalScheduler", **args):
     global _GlobalScheduler
     if _GlobalScheduler is None:
         with _GLobalSchedulerLock:
             if _GlobalScheduler is None:
                 _GlobalScheduler = Scheduler(name=name, **args)
+    return _GlobalScheduler
 
 def schedule_job(fcn, *params, **args):
-    global _GlobalScheduler
-    init_global_scheduler()         # init if needed
-    return _GlobalScheduler.add(fcn, *params, **args)
+    return global_scheduler().add(fcn, *params, **args)
+
+def unschedule_job(job_or_id):
+    return global_scheduler().remove(job_or_id)
+
+schedule_task = schedule_job        # aliases, deprecating term "job"
+unschedule_task = unschedule_job
 
 if __name__ == "__main__":
     from datetime import datetime
